avro\_to\_python.reader package
===============================

Submodules
----------

avro\_to\_python.reader.read module
-----------------------------------

.. automodule:: avro_to_python.reader.read
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: avro_to_python.reader
   :members:
   :undoc-members:
   :show-inheritance:
